@@ -4,7 +4,7 @@ test_that("flows dataset has more than 0 row", {
 
 test_that("flows dataset has the correct column names", {
   cn <- c("year", "coo_name", "coo", "coo_iso", "coa_name", "coa", "coa_iso",
-          "refugees", "asylum_seekers", "returned_refugees", "oip")
+          "refugees", "asylum_seekers", "refugee_like", "oip")
   expect_equal(cn, names(flows))
 })
 
@@ -18,6 +18,6 @@ test_that("flows dataset columns have the right type", {
   expect_type(flows[["coa_iso"]], "character")
   expect_type(flows[["refugees"]], "double")
   expect_type(flows[["asylum_seekers"]], "double")
-  expect_type(flows[["returned_refugees"]], "double")
+  expect_type(flows[["refugee_like"]], "double")
   expect_type(flows[["oip"]], "double")
 })
